@@ -87,11 +87,13 @@ typedef struct netsnmp_priv_alg_info_s {
     NETSNMP_IMPORT
     oid *           sc_get_auth_oid(int auth_type, size_t *oid_len);
     NETSNMP_IMPORT
-    netsnmp_auth_alg_info * sc_get_auth_alg_byoid(const oid *oid, u_int len);
+    const netsnmp_auth_alg_info *
+    sc_find_auth_alg_byoid(const oid *oid, u_int len);
     NETSNMP_IMPORT
-    netsnmp_auth_alg_info * sc_get_auth_alg_bytype(u_int type);
+    const netsnmp_auth_alg_info *
+    sc_find_auth_alg_bytype(u_int type);
     NETSNMP_IMPORT
-    netsnmp_auth_alg_info * sc_get_auth_alg_byindex(u_int index);
+    const netsnmp_auth_alg_info * sc_get_auth_alg_byindex(u_int index);
 
     /** deprectated, use
      *        sc_get_authtype() + sc_get_proper_auth_length_bytype() */
@@ -116,11 +118,12 @@ typedef struct netsnmp_priv_alg_info_s {
     NETSNMP_IMPORT
     int             sc_get_proper_priv_length_bytype(int privtype);
     NETSNMP_IMPORT
-    netsnmp_priv_alg_info * sc_get_priv_alg_byoid(const oid *oid, u_int len);
+    const netsnmp_priv_alg_info *
+    sc_get_priv_alg_byoid(const oid *oid, u_int len);
     NETSNMP_IMPORT
-    netsnmp_priv_alg_info * sc_get_priv_alg_bytype(u_int type);
+    const netsnmp_priv_alg_info * sc_get_priv_alg_bytype(u_int type);
     NETSNMP_IMPORT
-    netsnmp_priv_alg_info * sc_get_priv_alg_byindex(u_int index);
+    const netsnmp_priv_alg_info * sc_get_priv_alg_byindex(u_int index);
 
     NETSNMP_IMPORT
     int             sc_init(void);
