@@ -1,7 +1,7 @@
 #ifndef SNMPUDPBASEDOMAIN_H
 #define SNMPUDPBASEDOMAIN_H
 
-config_require(SocketBase)
+config_require(SocketBase);
 
 #include <net-snmp/library/snmp_transport.h>
 
@@ -9,23 +9,29 @@ config_require(SocketBase)
 extern          "C" {
 #endif
 
+/*
+ * "Constructor" for transport domain object.  
+ */
+
+    void netsnmp_udp_base_ctor(void);
+
 /*
  * Prototypes
  */
     void _netsnmp_udp_sockopt_set(int fd, int local);
     int netsnmp_udpbase_recv(netsnmp_transport *t, void *buf, int size,
                              void **opaque, int *olength);
-    int netsnmp_udpbase_send(netsnmp_transport *t, void *buf, int size,
+    int netsnmp_udpbase_send(netsnmp_transport *t, const void *buf, int size,
                              void **opaque, int *olength);
 
-#if defined(linux) && defined(IP_PKTINFO) \
-    || defined(IP_RECVDSTADDR) && !defined(_MSC_VER)
+#if defined(HAVE_IP_PKTINFO) || defined(HAVE_IP_RECVDSTADDR)
     int netsnmp_udpbase_recvfrom(int s, void *buf, int len,
                                  struct sockaddr *from, socklen_t *fromlen,
                                  struct sockaddr *dstip, socklen_t *dstlen,
                                  int *if_index);
-    int netsnmp_udpbase_sendto(int fd, struct in_addr *srcip, int if_index,
-                               struct sockaddr *remote, void *data, int len);
+    int netsnmp_udpbase_sendto(int fd, const struct in_addr *srcip,
+                               int if_index, const struct sockaddr *remote,
+                               const void *data, int len);
 #endif
 
 #ifdef __cplusplus
