@@ -4,7 +4,7 @@
 #include <net-snmp/types.h>
 #include <net-snmp/output_api.h>
 
-#if HAVE_SYSLOG_H
+#ifdef HAVE_SYSLOG_H
 #include <syslog.h>
 #endif
 #include <stdio.h>
@@ -83,8 +83,9 @@ extern          "C" {
     char *snmp_log_syslogname(const char *syslogname);
     typedef struct netsnmp_log_handler_s netsnmp_log_handler; 
     typedef int (NetsnmpLogHandler)(netsnmp_log_handler*, int, const char *);
-
+#ifndef NETSNMP_FEATURE_REMOVE_LOGGING_STDIO
     NetsnmpLogHandler log_handler_stdouterr;
+#endif /* NETSNMP_FEATURE_REMOVE_LOGGING_STDIO */
     NetsnmpLogHandler log_handler_file;
     NetsnmpLogHandler log_handler_syslog;
     NetsnmpLogHandler log_handler_callback;
