@@ -6,8 +6,6 @@
 
 #undef bsdlike
 
-#define ARP_SCAN_FOUR_ARGUMENTS
-
 /* uncomment this to read process names from /proc/X/cmdline (like <= 5.0) */
 /* #define USE_PROC_CMDLINE */
 
@@ -20,4 +18,3 @@
 
 /* define the extra mib modules that are supported */
 #define NETSNMP_INCLUDE_HOST_RESOURCES
-#define NETSNMP_INCLUDE_IFTABLE_REWRITES
