@@ -1,10 +1,8 @@
+#define __NetBSD_Version__ 1
 #include "netbsd.h"
 
 #define netbsd1 netbsd1         /* we're really close to this */
 #define openbsd openbsd
-#define openbsd3 openbsd3
-#define openbsd4 openbsd4
-#define openbsd5 openbsd5
 #define UVM
 
 #undef MBPOOL_SYMBOL
@@ -18,4 +16,3 @@
 
 /* define the extra mib modules that are supported */
 #define NETSNMP_INCLUDE_HOST_RESOURCES
-#define NETSNMP_INCLUDE_IFTABLE_REWRITES
